@@ -30,19 +30,19 @@
 
 struct _EditorPropertiesDialog
 {
-  GtkWindow       parent_instance;
+  AdwWindow       parent_instance;
 
   EditorDocument *document;
 
-  GtkLabel       *all_chars;
-  GtkLabel       *chars;
-  GtkLabel       *lines;
+  AdwActionRow   *all_chars;
+  AdwActionRow   *chars;
+  AdwActionRow   *lines;
   GtkLabel       *location;
-  GtkLabel       *name;
-  GtkLabel       *words;
+  AdwActionRow   *name;
+  AdwActionRow   *words;
 };
 
-G_DEFINE_TYPE (EditorPropertiesDialog, editor_properties_dialog, GTK_TYPE_WINDOW)
+G_DEFINE_TYPE (EditorPropertiesDialog, editor_properties_dialog, ADW_TYPE_WINDOW)
 
 enum {
   PROP_0,
@@ -219,19 +219,19 @@ editor_properties_dialog_rescan (EditorPropertiesDialog *self)
                   &chars, &words, &white_chars);
 
   str = g_strdup_printf("%'d", lines);
-  gtk_label_set_label (self->lines, str);
+  adw_action_row_set_subtitle (self->lines, str);
   g_free (str);
 
   str = g_strdup_printf("%'d", words);
-  gtk_label_set_label (self->words, str);
+  adw_action_row_set_subtitle (self->words, str);
   g_free (str);
 
   str = g_strdup_printf("%'d", chars);
-  gtk_label_set_label (self->all_chars, str);
+  adw_action_row_set_subtitle (self->all_chars, str);
   g_free (str);
 
   str = g_strdup_printf("%'d", chars - white_chars);
-  gtk_label_set_label (self->chars, str);
+  adw_action_row_set_subtitle (self->chars, str);
   g_free (str);
 }
 
@@ -254,8 +254,10 @@ editor_properties_dialog_set_document (EditorPropertiesDialog *self,
 
   if (g_set_object (&self->document, document))
     {
+      GFile *file = editor_document_get_file (document);
+
       g_object_bind_property (self->document, "title",
-                              self->name, "label",
+                              self->name, "subtitle",
                               G_BINDING_SYNC_CREATE);
       g_object_bind_property (self->document, "title",
                               self->name, "tooltip-text",
@@ -268,6 +270,9 @@ editor_properties_dialog_set_document (EditorPropertiesDialog *self,
                                    self->location, "tooltip-text",
                                    G_BINDING_SYNC_CREATE,
                                    file_to_tooltip, NULL, NULL, NULL);
+      gtk_widget_action_set_enabled (GTK_WIDGET (self),
+                                     "open-folder",
+                                     file != NULL);
       g_signal_connect_object (self->document,
                                "save",
                                G_CALLBACK (editor_properties_dialog_save_cb),
@@ -314,6 +319,20 @@ activate_link_cb (EditorPropertiesDialog *self,
   return editor_file_manager_show (file, NULL);
 }
 
+static void
+open_folder_cb (GtkWidget  *widget,
+                const char *action_name,
+                GVariant   *param)
+{
+  EditorPropertiesDialog *self = (EditorPropertiesDialog *)widget;
+  GFile *file = NULL;
+
+  g_assert (EDITOR_IS_PROPERTIES_DIALOG (self));
+
+  if ((file = editor_document_get_file (self->document)))
+    editor_file_manager_show (file, NULL);
+}
+
 static void
 win_close_cb (GtkWidget  *widget,
               const char *action_name,
@@ -396,8 +415,10 @@ editor_properties_dialog_class_init (EditorPropertiesDialogClass *klass)
   gtk_widget_class_bind_template_child (widget_class, EditorPropertiesDialog, location);
   gtk_widget_class_bind_template_child (widget_class, EditorPropertiesDialog, name);
   gtk_widget_class_bind_template_child (widget_class, EditorPropertiesDialog, words);
+
   gtk_widget_class_bind_template_callback (widget_class, activate_link_cb);
 
+  gtk_widget_class_install_action (widget_class, "open-folder", NULL, open_folder_cb);
   gtk_widget_class_install_action (widget_class, "win.close", NULL, win_close_cb);
 
   gtk_widget_class_add_binding_action (widget_class, GDK_KEY_Escape, 0, "win.close", NULL);
