@@ -26,22 +26,15 @@
 
 #define SHARED_CSS \
   "@define-color card_fg_color @window_fg_color;\n" \
-  "@define-color headerbar_fg_color @window_fg_color;\n" \
   "@define-color headerbar_border_color @window_fg_color;\n" \
   "@define-color popover_fg_color @window_fg_color;\n" \
   "@define-color dialog_fg_color @window_fg_color;\n" \
   "@define-color dark_fill_bg_color @headerbar_bg_color;\n" \
-  "@define-color view_bg_color @card_bg_color;\n" \
   "@define-color view_fg_color @window_fg_color;\n"
 #define LIGHT_CSS_SUFFIX \
-  "@define-color popover_bg_color mix(@window_bg_color, white, .1);\n" \
-  "@define-color dialog_bg_color @window_bg_color;\n" \
-  "@define-color card_bg_color alpha(white, .6);\n"
+  "@define-color card_bg_color alpha(white, .8);\n"
 #define DARK_CSS_SUFFIX \
-  "@define-color popover_bg_color mix(@window_bg_color, white, 0.07);\n" \
-  "@define-color dialog_bg_color mix(@window_bg_color, white, 0.07);\n" \
-  "@define-color card_bg_color alpha(white, .08);\n" \
-  "@define-color view_bg_color darker(@window_bg_color);\n"
+  "@define-color card_bg_color alpha(white, .08);\n"
 
 enum {
   FOREGROUND,
@@ -256,10 +249,12 @@ _editor_recoloring_generate_css (GtkSourceStyleScheme *style_scheme)
 
   if (get_metadata_color (style_scheme, "window_bg_color", &color))
     define_color (str, "window_bg_color", &color);
-  else if (has_bg && has_fg)
+  else if (has_bg && has_fg && is_dark)
     define_color (str, "window_bg_color", &text_bg);
+  else if (has_bg && has_fg)
+    define_color_mixed (str, "window_bg_color", &text_bg, &text_fg, .03);
   else if (is_dark)
-    define_color_mixed (str, "window_bg_color", &text_bg, alt, .025);
+    define_color_mixed (str, "window_bg_color", &text_bg, &white, .025);
   else
     define_color_mixed (str, "window_bg_color", &text_bg, &white, .1);
 
@@ -274,12 +269,10 @@ _editor_recoloring_generate_css (GtkSourceStyleScheme *style_scheme)
 
   if (get_metadata_color (style_scheme, "headerbar_bg_color", &color))
     define_color (str, "headerbar_bg_color", &color);
-  else if (has_bg && has_fg)
-    define_color_mixed (str, "headerbar_bg_color", &text_bg, &text_fg, .085);
   else if (is_dark)
-    define_color_mixed (str, "headerbar_bg_color", &text_bg, alt, .025);
+    define_color_mixed (str, "headerbar_bg_color", &text_bg, &white, .07);
   else
-    define_color_mixed (str, "headerbar_bg_color", &text_bg, &white, .1);
+    define_color_mixed (str, "headerbar_bg_color", &text_bg, &white, .25);
 
   if (get_metadata_color (style_scheme, "headerbar_fg_color", &color))
     define_color (str, "headerbar_fg_color", &color);
@@ -290,7 +283,18 @@ _editor_recoloring_generate_css (GtkSourceStyleScheme *style_scheme)
   else
     define_color_mixed (str, "headerbar_fg_color", &text_bg, alt, .025);
 
-  define_color_mixed (str, "view_bg_color", &text_bg, &white, is_dark ? .1 : .3);
+  define_color_mixed (str, "popover_bg_color", &text_bg, &white, is_dark ? .07 : .25);
+
+  if (is_dark)
+    define_color_mixed (str, "dialog_bg_color", &text_bg, &white, .07);
+  else
+    define_color (str, "dialog_bg_color", &text_bg);
+
+  if (is_dark)
+    define_color_mixed (str, "view_bg_color", &text_bg, &black, .1);
+  else
+    define_color_mixed (str, "view_bg_color", &text_bg, &white, .3);
+
   define_color (str, "view_fg_color", &text_fg);
 
   if (get_metadata_color (style_scheme, "accent_bg_color", &color) ||
