@@ -1015,6 +1015,11 @@ editor_session_save_for_shutdown_cb (GObject      *object,
 
   if (!editor_session_save_finish (self, result, &error))
     g_warning ("Failed to save session: %s", error->message);
+
+  /* Ensure that we don't spin here on shutdown if we have some
+   * out of control text validation going on.
+   */
+  g_application_quit (g_application_get_default ());
 }
 
 void
@@ -1696,6 +1701,14 @@ editor_session_restore_v1_pages (EditorSession *self,
       if (uri != NULL)
         file = g_file_new_for_uri (uri);
 
+      if (file != NULL &&
+          g_file_is_native (file) &&
+          !g_file_query_exists (file, NULL))
+        {
+          g_clear_object (&file);
+          continue;
+        }
+
       /* If the file was also requested from command line arguments
        * and a +line:column was requested, prefer that to session state.
        */
@@ -1838,6 +1851,15 @@ editor_session_restore_v1 (EditorSession *self,
               continue;
             }
 
+          /* We might have restored session where all files and drafts were removed.
+           * In this case, we want to create a new draft page.
+           */
+          if (self->pages->len == 0)
+            {
+              g_autoptr(EditorDocument) document = editor_document_new_draft ();
+              editor_session_add_document (self, ewin, document);
+            }
+
           if (maximized)
             gtk_window_maximize (GTK_WINDOW (ewin));
 
