@@ -22,11 +22,9 @@
 
 #include <adwaita.h>
 
-#include "editor-binding-group.h"
 #include "editor-open-popover-private.h"
 #include "editor-page-private.h"
 #include "editor-position-label-private.h"
-#include "editor-signal-group.h"
 #include "editor-statusbar-private.h"
 #include "editor-window.h"
 
@@ -36,9 +34,11 @@ struct _EditorWindow
 {
   GtkApplicationWindow  parent_instance;
 
+  /* Cancellable which cancels when window closes */
+  GCancellable         *cancellable;
+
   /* Template Widgets */
   GtkWidget            *empty;
-  GtkWidget            *pages;
   AdwTabView           *tab_view;
   AdwTabBar            *tab_bar;
   GtkLabel             *title;
@@ -59,11 +59,12 @@ struct _EditorWindow
 
   /* Borrowed References */
   EditorPage           *visible_page;
+  EditorPage           *removing_page;
 
   /* Owned References */
-  EditorBindingGroup   *page_bindings;
-  EditorSignalGroup    *page_signals;
-  EditorSignalGroup    *document_signals;
+  GBindingGroup        *page_bindings;
+  GSignalGroup         *page_signals;
+  GSignalGroup         *document_signals;
   GSettings            *settings;
   GArray               *closed_items;
 
@@ -92,5 +93,6 @@ gboolean      _editor_window_request_close_page   (EditorWindow      *self,
 gboolean      _editor_window_request_close_pages  (EditorWindow      *self,
                                                    GList             *pages,
                                                    gboolean           close_saved);
+GCancellable *_editor_window_get_cancellable      (EditorWindow      *self);
 
 G_END_DECLS
